"""std_calibration: add chmod call before productfetcher
In addition, add pycapo as a transferred input file and specify in the script to use the transferred version
On top of that, specify which directories are to be copied back after completion of the calibration

Revision ID: 7d53b022c5b3
Revises: a118f3d0a99e
Create Date: 2021-05-25 13:58:24.131140

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "7d53b022c5b3"
down_revision = "a118f3d0a99e"
branch_labels = None
depends_on = None


def upgrade():
    script_contents = """#!/bin/sh
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
# Disabled until this is rewritten in Python
# ./deliver-cipl.sh ${PWD##*/}
"""
    op.execute(f"UPDATE workflow_templates SET content = E'{script_contents}' WHERE filename = 'std_calibration.sh'")

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )


def downgrade():
    script_contents = """#!/bin/sh
SCRIPTS_DIR=$(pycapo -q edu.nrao.workspaces.ProcessingSettings.scriptLocation)

export PATH=$PATH:${SCRIPTS_DIR}

./framework.sh -d .
cd rawdata/
./productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./deliver-cipl.sh ${PWD##*/}
"""
    op.execute(f"UPDATE workflow_templates SET content = E'{script_contents}' WHERE filename = 'std_calibration.sh'")

    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )
